# **RegiSoup**
A tool to convert \<figure> and \<xr> tags from deprecated MediaWiki extension to a new supported format as specified in the extension `Figures` available on: 
[https://www.mediawiki.org/wiki/Extension:Figures](https://www.mediawiki.org/wiki/Extension:Figures).